# Tidy3D (Beta release)

[![Notebooks](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/flexcompute-readthedocs/tidy3d-docs/readthedocs?labpath=docs%2Fsource%2Fnotebooks)
![tests](https://github.com/flexcompute/Tidy3D-client-revamp/actions/workflows//run_tests.yml/badge.svg)
[![Documentation Status](https://readthedocs.com/projects/flexcompute-tidy3ddocumentation/badge/?version=latest)](https://flexcompute-tidy3ddocumentation.readthedocs-hosted.com/en/latest/?badge=latest)
[![GitHub license](https://img.shields.io/github/license/Naereen/StrapDown.js.svg)](https://github.com/flexcompute/tidy3d/blob/main/LICENSE)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/tidy3d-beta.svg)](https://pypi.python.org/pypi/tidy3d-beta/)
[![PyPI version shields.io](https://img.shields.io/pypi/v/tidy3d-beta.svg)](https://pypi.python.org/pypi/tidy3d-beta/)


![](https://raw.githubusercontent.com/flexcompute/tidy3d/main/img/Tidy3D-logo.svg)

![](https://raw.githubusercontent.com/flexcompute/tidy3d/main/img/snippet.png)

## Installation

### Using pip

```
pip install tidy3d-beta
```

### From source

```
git clone https://github.com/flexcompute/tidy3d.git
cd tidy3d
pip install -e .
```

Can verify it worked by running

```
python -c "import tidy3d as td; print(td.__version__)"
```

and it should print out the version number, for example:

```
0.2.0
```

## Documentation

View our documentation [here](https://flexcompute-tidy3ddocumentation.readthedocs-hosted.com/en/latest/).
And see the source code (if you wish) [here](https://github.com/flexcompute-readthedocs/tidy3d-docs).

## Issues / Feedback / Bug Reporting

This is a beta release and your feedback helps us immensely!

If you find bugs, file an [Issue](https://github.com/flexcompute/tidy3d/issues).
For more general discussions, questions, comments, anything else, open a topic in the [Discussions Tab](https://github.com/flexcompute/tidy3d/discussions).

